<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 10/08/2005 *
 * ===================                          Last change: 01/01/2006 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : gen_sql_patches.php                              *
 * -------------------------------------------------------------------- *
 * Short description : Patch password system after upgrading            *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Patcht das Passwort-System nach DB-Update        *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * Needs to be in all Files and every File needs "svn propset           *
 * svn:keywords Date Revision" (autoprobset!) at least!!!!!!            *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009, 2010 by Mailer Developer Team                    *
 * For more information visit: http://www.mxchange.org                  *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	die();
}

// Check for version of sql_patches
if (isExtensionInstalledAndNewer('sql_patches', '0.3.6')) return false;

// Check if there is no scrambling string
if (getConfig('pass_scramble') == '') {
	// Generate 40 chars long scramble string
	$scrambleString = genScrambleString(40);

	// ... and store it there for future usage
	updateConfiguration('pass_scramble', $scrambleString);

	// Remove dummy string
	unset($scrambleString);
} // END - if

// Check if there is no master salt string
if (getConfig('master_salt') == '') {
	// Generate the master salt which is the first chars minus 40 chars of this random hash
	// We do an extra scrambling here...
	$masterSalt = scrambleString(sha1(generatePassword(mt_rand(128, 256))));

	// ... and store it there for future usage
	updateConfiguration('master_salt', $masterSalt);

	// Remove dummy string
	unset($masterSalt);
} // END - if

if (getConfig('file_hash') == '') {
	// Create filename from hashed random string
	$fileHash = sha1(generatePassword(mt_rand(128, 256)));
	$FQFN = sprintf("%sinc/.secret/.%s",
		getConfig('PATH'),
		$fileHash
	);

	// Generate secret key from a randomized string
	$secretKey = sha1(generateHash(mt_rand(128, 256)));

	// File hash was never created
	writeToFile($FQFN, $secretKey);

	// Is the file there?
	if (isFileReadable($FQFN)) {
		//* DEBUG: */ removeFile($FQFN);
		//* DEBUG: */ $test = hexdec(getSession('u_hash')) / hexdec($secretKey);
		//* DEBUG: */ $test = generateHash(str_replace('.', '', $test));
		//* DEBUG: */ die("Secret-Key: ".$secretKey."<br />Cookie: ".getSession('u_hash')."<br />Test: ".$test);

		// Write $fileHash to database
		updateConfiguration('file_hash', $fileHash);

		// Generate FQFN for .htaccess file
		$FQFN = sprintf("%sinc/.secret/.htaccess",
			getConfig('PATH')
		);

		// Is the .htaccess file there?
		if (!isFileReadable($FQFN)) {
			// Also create .htaccess file
			writeToFile($FQFN, "Deny from all\n");
		} // END - if

		// Also update configuration
		setConfigEntry('secret_key', $secretKey);

		// Remove variables
		unset($secretKey);
		unset($fileHash);
	} // END - if
} // END - if

// [EOF]
?>
